<?php
/**
 * Plugin Name: Difluir Comment Email Reply
 * Plugin URI:  https://difluir.com/
 * Description: Comment email reply.
 * Version:     1.0.0
 * Author:      Difluir
 * Author URI:  https://difluir.com/
 * Text Domain: difluir-cer
 * Domain Path: /languages
 *
 * @package difluir-cer
 * @author  Difluir
 */

if ( ! defined('ABSPATH') ) {
    exit;
}

final class Difluir_Comment_Email_Reply {

    public function __construct() {
        add_action( 'init', array( $this, 'difluir_cer_setup' ), -1 );
        add_action( 'init', array( $this, 'init_lang' ), 0 );
    }

    public function difluir_cer_setup() {
        add_action( 'wp_insert_comment',     array( $this, 'difluir_cer_notification' ),   99, 2 );
        add_action( 'wp_set_comment_status', array( $this, 'difluir_cer_status_changed' ), 99, 2 );
    }

    public function init_lang() {
        $plugin_header_translate = __( 'Comment email reply.', 'difluir-cer' );    
        load_plugin_textdomain( 'difluir-cer', FALSE, basename( dirname( __FILE__ ) ) . '/languages' );
    }

    public function difluir_cer_notification( $comment_id, $comment_object ) {
        if ( $comment_object->comment_approved == 1 && $comment_object->comment_parent > 0 ) {
            $admin_email = get_option('admin_email');

            $comment_parent = get_comment($comment_object->comment_parent);

            $mailcontent  = __('Hello', 'difluir-cer').' <strong>'.$comment_parent->comment_author.'</strong>, ';
            $mailcontent .= '<br><br>';
            $mailcontent .= '<strong>'.$comment_object->comment_author.'</strong> '.esc_attr( __('replied to your comment on', 'difluir-cer') ).' <strong>'.get_the_title( $comment_parent->comment_post_ID ).'</strong>:';
            $mailcontent .= '<br><br>';
            $mailcontent .= '<em>'.$comment_object->comment_content.'</em>';
            $mailcontent .= '<br><br>';
            $mailcontent .= esc_attr( __('Go to it or reply:', 'difluir-cer') ).' <a href="'.esc_url(get_comment_link( $comment_parent->comment_ID )).'" target="_blank">'.esc_url(get_comment_link( $comment_parent->comment_ID )).'</a>';
            $mailcontent .= '<br>';
            $mailcontent .= '<strong>'.esc_attr( __('Please, do not reply this email.', 'difluir-cer') ).'</strong><br><br>';

            $email_to = $comment_parent->comment_author_email;

            if ( $email_to == $admin_email ) {
                return;
            }

            $sitename = strtolower( $_SERVER['SERVER_NAME'] );
            $sitename = ( substr( $sitename, 0, 4 ) == 'www.' ) ? substr( $sitename, 4 ) : preg_replace( '#^www\.#', '', $sitename );
            $email_sender = 'noreply@'.$sitename;

            $email_subject = '['.esc_attr( get_bloginfo('name') ).'] '.esc_attr( __('New reply to your Comment', 'difluir-cer') );
           
            $headers_break = ( PHP_OS == "WINNT" ) ? "\r\n" : "\n";

            $headers  = "MIME-Version: 1.1".$headers_break;
            $headers .= "Content-type: text/html; charset=".get_option('blog_charset')."".$headers_break;
            $headers .= "From: ".esc_attr( get_bloginfo('name') )." <".$email_sender.">".$headers_break;

            if ( function_exists('wp_mail') ) {
                wp_mail( $email_to, $email_subject, $mailcontent, $headers );
            } elseif ( function_exists('mail') ) {
                mail( $email_to, $email_subject, $mailcontent, $headers );
            }
        }
    }

    public function difluir_cer_status_changed( $comment_id, $comment_status ) {
        $comment_object = get_comment( $comment_id );
        if ( $comment_status == 'approve' ) {
            $this->difluir_cer_notification( $comment_object->comment_ID, $comment_object );
        } 
    }

}

function dldcer_comment_main() {    
    new Difluir_Comment_Email_Reply();
}
add_action( 'plugins_loaded', 'dldcer_comment_main' );

function dldcer_comment_deactivation() {
    remove_action( 'plugins_loaded', 'dldcer_comment_main' );
}

register_deactivation_hook( __FILE__, 'dldcer_comment_deactivation' );
register_uninstall_hook( __FILE__, 'dldcer_comment_deactivation' );

?>